==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/GetInAppMessagesRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetInAppMessagesRequest(
    applicationId: __string,
    endpointId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetInAppMessagesRequest = {
    import GetInAppMessagesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetInAppMessagesRequest
      .builder()
      .applicationId(__string.unwrap(applicationId): java.lang.String)
      .endpointId(__string.unwrap(endpointId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GetInAppMessagesRequest.ReadOnly =
    zio.aws.pinpoint.model.GetInAppMessagesRequest.wrap(buildAwsValue())
}
object GetInAppMessagesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetInAppMessagesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetInAppMessagesRequest =
      zio.aws.pinpoint.model.GetInAppMessagesRequest(applicationId, endpointId)
    def applicationId: __string
    def endpointId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getEndpointId: ZIO[Any, Nothing, __string] = ZIO.succeed(endpointId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetInAppMessagesRequest
  ) extends zio.aws.pinpoint.model.GetInAppMessagesRequest.ReadOnly {
    override val applicationId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.applicationId())
    override val endpointId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.endpointId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetInAppMessagesRequest
  ): zio.aws.pinpoint.model.GetInAppMessagesRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpoint_3-6.20.78.3-sources.jar: zio/aws/pinpoint/model/GetInAppMessagesRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetInAppMessagesRequest(
    applicationId: __string,
    endpointId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetInAppMessagesRequest = {
    import GetInAppMessagesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetInAppMessagesRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .endpointId(endpointId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GetInAppMessagesRequest.ReadOnly =
    zio.aws.pinpoint.model.GetInAppMessagesRequest.wrap(buildAwsValue())
}
object GetInAppMessagesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetInAppMessagesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetInAppMessagesRequest =
      zio.aws.pinpoint.model.GetInAppMessagesRequest(applicationId, endpointId)
    def applicationId: __string
    def endpointId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getEndpointId: ZIO[Any, Nothing, __string] = ZIO.succeed(endpointId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetInAppMessagesRequest
  ) extends zio.aws.pinpoint.model.GetInAppMessagesRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
    override val endpointId: __string = impl.endpointId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetInAppMessagesRequest
  ): zio.aws.pinpoint.model.GetInAppMessagesRequest.ReadOnly = new Wrapper(impl)
}
